---
layout: template
title: Roadmap
permalink: /documentation/roadmap/
link_group: documentation
---
# Roadmap

Here you can read about what is planned for upcoming versions, at least hints of it.

## Upcoming versions

### 0.4.0

**Focus:** Support for the Media Remote Protocol (MRP) used by tvOS

**Issues:** [Milestone on GitHub](https://github.com/postlund/pyatv/milestone/2)

#### 0.4.1

**Focus:** Bug fixes and environmental clean ups, e.g. fixing scripts and improve build environment

**Issues:** [Milestone on GitHub](https://github.com/postlund/pyatv/milestone/3)

### 0.5.0

**Focus:** Improved AirPlay support (in general)

**Issues:** [Milestone on GitHub](https://github.com/postlund/pyatv/milestone/4)
